@@ -7,6 +7,7 @@ import logging
 from uuid import uuid1
 from datetime import datetime
 from contextlib import contextmanager
+from collections import namedtuple
 
 import amqp
 
@@ -25,21 +26,18 @@ class Task(object):
         The failed task will be retried in the same worker.
     :param max_run_time: Maximum allowed time in seconds for task to
         complete.
-    :param fail_delay: Seconds to wait before sending failed message
-        back to queue.
     :param reject_delay: Seconds to wait before sending rejected message
         back to queue.
 
     """
     def __init__(self, f, kuyruk, queue,
                  retry=0, max_run_time=None,
-                 fail_delay=0, reject_delay=0):
+                 reject_delay=0):
         self.f = f
         self.kuyruk = kuyruk
         self.queue = queue
         self.retry = retry
         self.max_run_time = max_run_time
-        self.fail_delay = fail_delay
         self.reject_delay = reject_delay
         self._send_signal(signals.task_init)
 
@@ -56,6 +54,9 @@ class Task(object):
         logger.debug("Task.__call__ args=%r, kwargs=%r", args, kwargs)
         self.send_to_queue(args, kwargs)
 
+    def subtask(self, args=(), kwargs={}, host=None):
+        return SubTask(self, args, kwargs, host)
+
     def send_to_queue(self, args=(), kwargs={},
                       host=None, wait_result=None, message_ttl=None):
         """
@@ -197,8 +198,15 @@ class Task(object):
         return name
 
 
+SubTask = namedtuple("SubTask", ("task", "args", "kwargs", "host"))
+
+
 @contextmanager
 def time_limit(seconds):
+    if seconds == 0:
+        yield
+        return
+
     def signal_handler(signum, frame):
         raise Timeout
     signal.signal(signal.SIGALRM, signal_handler)
