@@ -10,6 +10,7 @@ import threading
 import traceback
 import multiprocessing
 
+import six
 import amqp
 from monotonic import monotonic
 
@@ -43,6 +44,7 @@ class Worker(object):
 
         self._hostname = socket.gethostname()
         self.queues = [add_host(q) for q in args.queues]
+        self._tasks = {}
         self.shutdown_pending = threading.Event()
         self.consuming = False
         self.current_task = None
@@ -187,6 +189,8 @@ class Worker(object):
             return
 
         try:
+            if isinstance(message.body, six.binary_type):
+                message.body = message.body.decode('utf-8')
             description = json.loads(message.body)
         except Exception:
             message.channel.basic_reject(message.delivery_tag, requeue=False)
@@ -197,8 +201,8 @@ class Worker(object):
 
     def _process_description(self, message, description):
         try:
-            task = importer.import_object(description['module'],
-                                          description['function'])
+            task = self._import_task(description['module'],
+                                     description['function'])
             args, kwargs = description['args'], description['kwargs']
         except Exception:
             logger.error('Cannot import task')
@@ -209,6 +213,14 @@ class Worker(object):
         else:
             self._process_task(message, description, task, args, kwargs)
 
+    def _import_task(self, module, function):
+        if (module, function) in self._tasks:
+            return self._tasks[(module, function)]
+
+        task = importer.import_object(module, function)
+        self._tasks[(module, function)] = task
+        return task
+
     def _process_task(self, message, description, task, args, kwargs):
         queue = message.delivery_info['routing_key']
         reply_to = message.properties.get('reply_to')
@@ -242,8 +254,7 @@ class Worker(object):
                                         task=task, args=args, kwargs=kwargs,
                                         exc_info=exc_info, worker=self,
                                         queue=queue)
-            self._rejects.push(task.fail_delay, message.delivery_tag,
-                               requeue=False)
+            self._rejects.push(0, message.delivery_tag, requeue=False)
             if reply_to:
                 self._send_reply(reply_to, message.channel, None, exc_info)
         else:
